#[non_exhaustive]pub enum ComposeFindingStage {
Load,
Interpolation,
Merge,
ProfileSelection,
ProjectModel,
Validation,
}Expand description
Compose processing layer that emitted a retained native finding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Load
YAML syntax or single-document loading.
Interpolation
Explicit variable interpolation.
Merge
Ordered multi-document merge.
ProfileSelection
Explicit service profile selection.
ProjectModel
Native merged-project typing.
Validation
Provider/runtime compatibility validation.
Implementations
Sourceimpl ComposeFindingStage
impl ComposeFindingStage
Sourcepub fn native_finding(self, diagnostic: &ComposeDiagnostic) -> NativeFinding
pub fn native_finding(self, diagnostic: &ComposeDiagnostic) -> NativeFinding
Converts one native diagnostic into the shared protected finding envelope.